import { Twitter, Instagram, Globe } from 'lucide-react';
import {useEffect, useState} from "react";
import axios from "axios";
import { Author } from "../types/auth.ts";
import { Link } from 'react-router-dom';


export function AuthorsSection() {
  const [authors, setAuthors] = useState<Author[]>([]);

  // Загрузка авторов
  useEffect(() => {
    const fetchAuthors = async () => {
      try {
        const response = await axios.get('/api/authors/');
        setAuthors(response.data);
      } catch (error) {
        console.error('Ошибка загрузки авторов:', error);
      }
    };

    fetchAuthors();
  }, []);

  return (
      <section className="py-16 px-4 sm:px-6 lg:px-8 max-w-7xl mx-auto">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold text-gray-900">Наши авторы</h2>
          <p className="mt-4 text-lg text-gray-600 max-w-2xl mx-auto">
            Познакомьтесь с талантливыми писателями и экспертами, работающими для Вас
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {authors.map((author) => (
              <div key={author.id} className="bg-white rounded-lg shadow-md overflow-hidden transition-transform hover:scale-[1.02] h-full">
                <div className="p-6 flex flex-col flex-grow min-h-[200px] h-full">
                  <div className="flex items-center mb-4">
                    <img
                        src={author.avatarUrl}
                        alt={author.displayName}
                        className="w-24 h-24 rounded-full object-cover mr-4"
                    />
                    <div>
                      <h3 className="text-xl font-bold text-gray-900">{author.displayName}</h3>
                      <div className="flex mt-2 space-x-2">
                        <a href="#" className="text-gray-400 hover:text-blue-500 transition-colors">
                          <Twitter size={18} />
                        </a>
                        <a href="#" className="text-gray-400 hover:text-pink-500 transition-colors">
                          <Instagram size={18} />
                        </a>
                        <a href="#" className="text-gray-400 hover:text-gray-700 transition-colors">
                          <Globe size={18} />
                        </a>
                      </div>
                    </div>
                  </div>
                  <p className="text-gray-600">{author.bio}</p>

                  <div className="mt-auto pt-6 border-t border-gray-100">
                    <div className="flex justify-between items-center">
                      <span className="text-sm text-gray-500">
                        {author.articlesCount} статей
                      </span>
                      <Link
                          to={`/search?author=${author.id}`}
                          className="text-blue-600 hover:text-blue-800 text-sm font-medium"
                      >
                        Статьи автора →
                      </Link>
                    </div>
                  </div>
                </div>
              </div>
          ))}
        </div>
      </section>
  );
}