import { Link } from 'react-router-dom';
import { Mail, Phone, Instagram, Twitter, Facebook, ExternalLink } from 'lucide-react';
import { DesignStudioLogo } from './DesignStudioLogo';

export function Footer() {
  return (
    <footer className="bg-gray-900 text-gray-300">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
          {/* About Section */}
          <div className="col-span-2">
            <h2 className="text-xl font-bold text-white mb-4">О нас</h2>
            <p className="text-gray-400 mb-4">
              Культура двух столиц - это главное место, где вы можете найти информацию об искусстве и культуре.
              Основав портал в 2015 году, мы предлагаем вам самые свежие новости о кино,
              театре, музыке, спорте и культуре Москвы и Санкт-Петербурга.
            </p>
            <div className="flex space-x-4">
              <a href="https://twitter.com" className="hover:text-white transition-colors">
                <img src="/images/ok-11.svg" alt="" width="20" height="20"/>
              </a>
              <a href="https://facebook.com" className="hover:text-white transition-colors">
                <Facebook size={20}/>
              </a>
              <a href="https://instagram.com" className="hover:text-white transition-colors">
                <Instagram size={20}/>
              </a>
            </div>
          </div>

          {/* Quick Links */}
          <div>
            <h3 className="text-lg font-semibold text-white mb-4">Быстрые ссылки</h3>
            <ul className="space-y-2">
              <li>
                <Link to="/?category=Film" className="hover:text-white transition-colors">
                  Кино
                </Link>
              </li>
              <li>
                <Link to="/?category=Theater" className="hover:text-white transition-colors">
                  Театр
                </Link>
              </li>
              <li>
                <Link to="/?category=Music" className="hover:text-white transition-colors">
                  Музыка
                </Link>
              </li>
              <li>
                <Link to="/?category=Sports" className="hover:text-white transition-colors">
                  Спорт
                </Link>
              </li>
              <li>
                <Link to="/?category=Art" className="hover:text-white transition-colors">
                  Исскуство
                </Link>
              </li>
              <li>
                <Link to="/?category=Legends" className="hover:text-white transition-colors">
                  Легенды
                </Link>
              </li>
              <li>
                <Link to="/?category=Anniversaries" className="hover:text-white transition-colors">
                  Юбилеи
                </Link>
              </li>
              <li>
                <Link to="/?category=Memory" className="hover:text-white transition-colors">
                  Память
                </Link>
              </li>
            </ul>
          </div>

          {/* Contact Info */}
          <div>
            <h3 className="text-lg font-semibold text-white mb-4">Контакты</h3>
            <ul className="space-y-4">
              <li className="flex items-center">
                <Mail size={18} className="mr-2" />
                <a href="mailto:contact@culturescope.com" className="hover:text-white transition-colors">
                  izolkin@yandex.ru
                </a>
              </li>
              <li className="flex items-center">
                <Phone size={18} className="mr-2" />
                <a href="tel:+1234567890" className="hover:text-white transition-colors">
                  (123) 456-7890
                </a>
              </li>
            </ul>

            <h3 className="text-lg font-semibold text-white mt-6 mb-4">Наши партнеры</h3>
            <ul className="space-y-2">
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://excurspb.ru" className="hover:text-white transition-colors">
                  Туроператор «Прогулки»
                </a>
              </li>
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://royalalberthall.com" className="hover:text-white transition-colors">
                  Royal Albert Hall
                </a>
              </li>
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://nationaltheatre.org.uk" className="hover:text-white transition-colors">
                  National Theatre
                </a>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-gray-800 mt-12 pt-8">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <div className="flex items-center space-x-2">
              <p className="text-sm text-gray-400">
                © {new Date().getFullYear()} Культура двух столиц. Все права защищены.
              </p>
              <span className="text-gray-600">•</span>
              <DesignStudioLogo />
            </div>
            <div className="flex space-x-6 mt-4 md:mt-0">
              <Link to="/privacy" className="text-sm text-gray-400 hover:text-white transition-colors">
                Privacy Policy
              </Link>
              <Link to="/terms" className="text-sm text-gray-400 hover:text-white transition-colors">
                Terms of Service
              </Link>
              <Link to="/sitemap" className="text-sm text-gray-400 hover:text-white transition-colors">
                Sitemap
              </Link>
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
}