import React, { useRef } from 'react';
import { Image as ImageIcon } from 'lucide-react';
import {Editor} from "@tiptap/react";
import {imageResolutions} from "../config/imageResolutions.ts";
import axios from "axios";


interface TipTapImageUploadButtonProps {
  editor: Editor; // Replace with your TipTap editor type
  articleId: string;
}

const TipTapImageUploadButton: React.FC<TipTapImageUploadButtonProps> = ({ editor, articleId }) => {
  const fileInputRef = useRef<HTMLInputElement>(null);

  if (!editor) {
    return null;
  }

  // Обработка выбранного изображения
  const handleFileChange = async (event: React.ChangeEvent<HTMLInputElement>) => {
    const file = event.target.files?.[0];
    if (!file) return;

    try {
      // Проверка разрешения изображения
      const resolution = imageResolutions.find(r => r.id === 'large');
      if (!resolution)
        throw new Error('Invalid resolution');

      const formData = new FormData();
      formData.append('file', file);
      formData.append('resolutionId', resolution.id);
      formData.append('folder', 'articles/' + articleId);

      // Отправка запроса на сервер
      const response = await axios.post('/api/images/upload-url', formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
          'Authorization': `Bearer ${localStorage.getItem('token')}`, // Передача токена аутентификации
        },
      });

      if (response.data?.fileUrl) {
        editor.chain().focus().setImage({src: response.data.fileUrl}).run();
      }
    } catch (error) {
      console.error('Upload error:', error);
    }

/*
    const reader = new FileReader();
    reader.onload = (e) => {
      const src = e.target?.result as string;
      // Insert the image with the TipTap editor
      editor.chain().focus().setImage({src}).run();
    };
    reader.readAsDataURL(file);
*/

    // Reset the file input
    if (fileInputRef.current) {
      fileInputRef.current.value = '';
    }
  };

  // Function to trigger file input click
  const handleButtonClick = () => {
    fileInputRef.current?.click();
  };

  return (
      <div className="relative inline-block">
        <button
            type="button"
            onClick={handleButtonClick}
            className="p-1 rounded hover:bg-gray-200"
            title="Вставить изображение"
        >
          <ImageIcon size={18} />
        </button>
        <input
            ref={fileInputRef}
            type="file"
            accept="image/*"
            onChange={handleFileChange}
            className="hidden"
        />
      </div>
  );
};

export default TipTapImageUploadButton;
